Todo list
=========

- Really need to parallelize calls to preprocessing/ghostscript 
- Run more robustness tests for watching networked shares
- Add more docstrings
- Add more option specifiers to tesseract and ghostscript
